Description Details References
demc2 implements both the origal Markovian demc version of ter Braak (2006) and
the egodic demc_zc version of ter Braak & Vrugt (2008) using learning from the past and the snooker update.
Convergence can be checked with coda.
The demc package allows restarts.
The functions that you're likely need from demc are
demc and demc_zs for generating samples and
as.coda to be able to use package coda for convergence checks
ter Braak, C. J. F. (2006). A Markov Chain Monte Carlo version of the genetic algorithm Differential Evolution: easy Bayesian computing for real parameter spaces. Statistics and Computing, 16, 239-249.http://edepot.wur.nl/26336 ter Braak C. J. F., and Vrugt J. A. (2008). Differential Evolution Markov Chain with snooker updater and fewer chains. Statistics and Computing, 18 (4), 435-446. http://dx.doi.org/10.1007/s11222-008-9104-9
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.